module SubmissionController
    extend ActiveSupport::Concern
    include ::Paginator

    included do
        before_action :set_new_submission, only: :submit
        before_action :authorize!
    end

    def submissions
        learning_objects = paginate LearningObject.where(state: LearningObject.states[:submitted])
        render json: learning_objects
    end

    def submit
        return render status: :ok if @learning_object.submitted?

        if @learning_object.update(state: LearningObject.states[:submitted])
            render json: @learning_object, status: :ok
        else
            render json: @learning_object.errors, status: :unprocessable_entity
        end
    end

    private

    def submitted
        return @learning_object.submitted?
    end

    def set_new_submission
        @learning_object = LearningObject.find(params[:id])
    end

end
