class V1::ContactsController < ApplicationController
  include ::Paginator

  before_action :set_contact, only: [:show, :update, :destroy]

  # GET v1/contacts
  def index
    contacts = paginate Contact
    render json: contacts
  end

  # GET v1/contacts/1
  def show
    render json: @contact
  end

  # POST v1/contacts
  def create
    @contact = Contact.new(contact_params)
    if @contact.save
      ContactsMailer.new_contact_received(@contact).deliver_now
      render json: @contact, status: :created
    else
      render json: @contact.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT v1/contacts/1
  def update
    if @contact.update(contact_params)
      ContactsMailer.contact_updated(@contact).deliver_now
      render json: @contact
    else
      render json: @contact.errors, status: :unprocessable_entity
    end
  end

  # DELETE v1/contacts/1
  def destroy
    @contact.destroy
    render status: :ok
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_contact
      @contact = Contact.find(params[:id])
    end

    # Only allow a trusted parameter "white list" through.
    def contact_params
      params.require(:contact).permit(:name, :email, :message)
    end
end
