class V1::InstitutionsController < ApplicationController
  include ::DeletedObjectsController
  include ::Paginator


  before_action :set_institution, only: [:show, :update, :destroy, :users]
  before_action :authenticate_user!, only: [:create, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET v1/institutions
  # GET v1/institutions.json
  def index
    institutions = paginate Institution
    render json: institutions
  end

  # GET v1/institutions/1
  # GET v1/institutions/1.json
  def show
    render json: @institution
  end

  # POST v1/institutions
  # POST v1/institutions.json
  def create
    institution = Institution.new(institution_params)
    authorize institution

    if institution.save
      render json: institution, status: :created
    else
      render json: institution.errors, status: :unprocessable_entity
    end
  end

  # PUT/PATCH /v1/institutions/1
  # PUT/PATCH /v1/institutions/1.json
  def update
    if @institution.update(institution_params)
      render json: @institution, status: :ok
    else
      render json: @institution.errors, status: :unprocessable_entity
    end
  end

  # DELETE v1/institutions/1
  # DELETE v1/institutions/1.json
  def destroy
    @institution.destroy
    render status: :ok
  end

  def users
    @users = @institution.users
    render json: @users, status: :ok
  end

  private

  def deleted_resource
    Institution
  end

  def set_institution
    @institution = Institution.find(params[:id])
  end

  def institution_params
    params.require(:institution).permit(:name, :description, :address, :city, :country)
  end

  def authorize!
    authorize @institution
  end

end
