class V1::LicensesController < ApplicationController
  before_action :authenticate_user!, only: [:create, :update, :destroy]
  before_action :set_license, only: [:show, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET /licenses
  # GET /licenses.json
  def index
    render json: License.all, each_serializer: LicenseSerializer
  end

  # GET /licenses/1
  # GET /licenses/1.json
  def show
    render json: @license
  end

  # POST /licenses
  # POST /licenses.json
  def create
    @license = License.new(license_params)
    authorize @license

    if @license.save
      render json: @license, status: :created
    else
      render json: @license.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT /licenses/1
  # PATCH/PUT /licenses/1.json
  def update
    @license = License.find(params[:id])

    if @license.update(license_params)
      head :no_content
    else
      render json: @license.errors, status: :unprocessable_entity
    end
  end

  # DELETE /licenses/1
  # DELETE /licenses/1.json
  def destroy
    @license.destroy

    head :no_content
  end

  private

  def set_license
    @license = License.find(params[:id])
  end

  def license_params
    params.require(:license).permit(:name, :description, :url, :image_url)
  end

  def authorize!
    authorize @license
  end
end
