class V1::MimeTypesController < ApplicationController
  include ::Paginator

  before_action :authenticate_user!, except: [:index, :show]
  before_action :set_mime_type, only: [:show, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET /mime_types
  # GET /mime_types.json
  def index
    mime_types = paginate MimeType
    render json: mime_types
  end

  # GET /mime_types/1
  # GET /mime_types/1.json
  def show
    render json: @mime_type
  end

  # POST /mime_types
  # POST /mime_types.json
  def create
    @mime_type = MimeType.new(mime_type_params)
    authorize @mime_type

    if @mime_type.save
      render json: @mime_type, status: :created
    else
      render json: @mime_type.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT /mime_types/1
  # PATCH/PUT /mime_types/1.json
  def update
    if @mime_type.update(mime_type_params)
      render json: @mime_type, status: :ok
    else
      render json: @mime_type.errors, status: :unprocessable_entity
    end
  end

  # DELETE /mime_types/1
  # DELETE /mime_types/1.json
  def destroy
    @mime_type.destroy
    render status: :ok
  end

  private

  # Use callbacks to share common setup or constraints between actions.
  def set_mime_type
    @mime_type = MimeType.find(params[:id])
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def mime_type_params
    params.require(:mime_type).permit(:extension, :mime_type)
  end

  def authorize!
    authorize @mime_type
  end
end
