class V1::RolesController < ApplicationController
  include ::Paginator

  before_action :authenticate_user!, except: [:index, :show]
  before_action :set_role, only: [:show, :update, :destroy]
  before_action :authorize!, only: [:update, :destroy]

  # GET /roles
  # GET /roles.json
  def index
    roles = paginate Role
    render json: roles
  end

  # GET /roles/1
  # GET /roles/1.json
  def show
    render json: @role
  end

  # POST /roles
  # POST /roles.json
  def create
    @role = Role.new(role_params)
    authorize @role

    if @role.save
      render json: @role, status: :created
    else
      render json: @role.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT /roles/1
  # PATCH/PUT /roles/1.json
  def update
    if @role.update(role_params)
      render json: @role, status: :ok
    else
      render json: @role.errors, status: :unprocessable_entity
    end
  end

  # DELETE /roles/1
  # DELETE /roles/1.json
  def destroy
    @role.destroy
    render status: :ok
  end

  private

  # Use callbacks to share common setup or constraints between actions.
  def set_role
    @role = Role.find(params[:id])
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def role_params
    params.require(:role).permit(:name, :description)
  end

  def authorize!
    authorize @role
  end
end
