class V1::SuggestionsController < ApplicationController
  include ::Paginator

  before_action :set_suggestion, only: [:show, :update, :destroy]

  # GET v1/suggestions
  def index
    suggestions= paginate Suggestion
    render json: suggestions
  end

  # GET v1/suggestions/1
  def show
    render json: @suggestion
  end

  # POST v1/suggestions
  def create
    @suggestion = Suggestion.new(suggestion_params)

    if @suggestion.save
      SuggestionsMailer.new_suggestion_received(@suggestion).deliver_now
      render json: @suggestion, status: :created
    else
      render json: @suggestion.errors, status: :unprocessable_entity
    end
  end

  # PATCH/PUT v1/suggestions/1
  def update
    if @suggestion.update(suggestion_params)
      SuggestionsMailer.suggestion_updated(@suggestion).deliver_now
      render json: @suggestion
    else
      render json: @suggestion.errors, status: :unprocessable_entity
    end
  end

  # DELETE v1/suggestions/1
  def destroy
    @suggestion.destroy
    render status: :ok
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_suggestion
      @suggestion = Suggestion.find(params[:id])
    end

    # Only allow a trusted parameter "white list" through.
    def suggestion_params
      params.require(:suggestion).permit(:name, :link, :description, :status)
    end
end
