module Tagger
  extend ActiveSupport::Concern

  included do
    has_many :taggings, as: :tagger, dependent: :destroy
  end

  # An tagger can tagging learning object and collection
  # Examples:
  # tagger.tag(LearningObject.find(1), with: "Tag")
  # tagger.tag(Collection.find(1), with: "Tag")
  def tag(taggable, with: [])
    with.each do |tag_name|
      tag = Tag.where(name: tag_name).first_or_create
      Tagging.where(tag: tag, tagger_id: id, tagger_type: self.class.name, taggable_id: taggable, taggable_type: taggable.class.name).first_or_create
    end
  end

  # An tagger can untagging learning object and collection
  # Examples:
  # tagger.untag(LearningObject.find(1), "Tag")
  # tagger.untag(Collection.find(1), "Tag")
  def untag(taggable, with: [])
    with.each do |tag_name|
      tag = Tag.find_by(name: tag_name)
      Tagging.where(tagger: self, tag: tag, taggable: taggable).destroy_all
    end
  end
end
