module Trackable
  extend ActiveSupport::Concern
  include PublicActivity::Common
  include ActivitiesFilterService

  included do
    after_create :new_create_activity
    before_destroy :new_destroy_activity
    after_update :new_update_activity
  end

  private

  def new_update_activity
    return nil if changed.blank?
    return new_activity(:update) if ignore_changes == %w(updated_at)
    filtered = changed.reject { |x| ignore_changes.include?(x) }
    new_activity(:update) unless filtered.empty?
  end

  def new_create_activity
    new_activity(:create)
  end

  def new_destroy_activity
    params = { name: self.try(:name)}
    new_activity(:destroy,params)
  end

  def new_activity(action,params=nil)
    create_activity(
      action,
      owner: activity_owner,
      recipient: activity_recipient,
      privacy: activity_privacy,
      parameters: params
    )
  end

  def ignore_changes
    %w(updated_at)
  end

  def activity_owner
    proc { |controller, model| model.try(:user) || model.try(:owner) || controller.try(:current_user) }
  end

  def activity_recipient
    proc { |_controller, model| model.try(:recipient) || model }
  end

  def activity_privacy
    proc { |_controller, model| model.try(:privacy) || 'public' }
  end
end
