module PackageService
  class Link
    def initialize(objects)
      @generator = Generator.new(objects)
    end

    def link
      link = get_package_link
      if link.nil?
        @generator.generate
        link = retrieve_link
      end
      link
    end

    private

    def get_package_link
      package = PackageItem.select("package_id").where(:packageable => @generator.objects).group("package_id")
      return nil if package.blank?
      link = Package.find(package.first.package_id).file_path
      if !File.exist?(Rails.root.join('public',link))
        Package.destroy(package.first.package_id)
        return nil
      end
      link
    end

    def retrieve_link
      if wait_job
        filename = @generator.filename

        filepath = PackageService.dirname+'/'+filename
        package = Package.create(file_path: filepath)
        package.add_items(@generator.objects)
        return package.file_path
      end

      nil
    end

    def wait_job
      unless File.exist?(PackageService.file_root(@generator.filename))
        Timeout.timeout(60) do
          begin
            sleep(1.0)
          end until File.exist?(PackageService.file_root(@generator.filename))
        end
      end
      true
    rescue Timeout::Error
      false
    end
  end
end
