class ScoreCalculatorService
  def initialize(object)
    @object = object
    @class = @object.class.name
    @value = nil
  end

  def calculate(values = nil)
    values = object_hash if values.nil?
    values = values.with_indifferent_access

    sum = @object.is_a?(User) ? calculate_user(values) : calculate_object(values)

    @value = (sum.to_f / sum_weights.to_f).round(6)
  end

  def category_by_reputation
    return nil if @value.nil?

    UserCategory.order(:reference).each do |uc|
      next if @value > uc.reference
      return uc.id
    end
  end

  private

  def object_hash
    Score.object_type(@object.class.name).map { |s| [s.code, @object.try(s.code)] }.to_h
  end

  def sum_weights
    Score.object_type(@object.class.name).pluck(:weight).inject(0.0) { |acc, elem| acc + elem }
  end

  def calculate_user(values)
    sum = 0.0
    Score.object_type(@object.class.name).find_each do |score|
      max = score.max_value.to_f
      next if max.zero?

      sum += (values[score.code].to_f / max) * score.weight.to_f
    end
    sum
  end

  def calculate_object(values)
    sum = 0.0
    Score.object_type(@object.class.name).find_each do |score|
      sum += values[score.code].to_f * score.weight.to_f
    end
    sum
  end
end
