module SearchService
  class Collection < Model
    def search
      ::Collection.search(body: mount_query, order: order_hash, page: @search.page, per_page: @search.results_per_page)
    end

    def autocomplete
      params = {  where: { privacy: 'public' },
                  fields: ['name^10', 'description', 'owner'] }
      result = ::Collection.search(@search.query, autocomplete_params.merge(params))

      thumbnail = proc { |_obj| '/assets/icons/collection' }
      type = proc { |_obj| 'Collection' }
      autocomplete_render(result, type, thumbnail)
    end

    private

    def search_fields
      [:name, :description, :author]
    end

    def mount_filter
      filter = []
      filter << { term: { privacy: 'public' } }
      filter << { in: { tags: @search.tags } } unless @search.tags.blank?
      filter << { in: { subjects: @search.subjects } } unless @search.subjects.blank?
      filter << { in: { educational_stages: @search.educational_stages } } unless @search.educational_stages.blank?
      filter << { terms: { empty: show_empty } }
      filter
    end

    def order_hash
      case @search.order
      when 'author' then { owner: { order: :asc, unmapped_type: :string } }
      when 'publicationasc' then { created_at: { order: :asc, unmapped_type: :timestamp } }
      when 'publicationdesc' then { created_at: { order: :desc, unmapped_type: :timestamp } }
      when 'title' then { name: { order: :asc, unmapped_type: :string } }
      when 'likes' then { likes: { order: :desc } }
      when 'downloads' then { downloads: { order: :desc } }
      when 'review_average' then { review_average: { order: :desc } }
      else "_score"
      end
    end

    def show_empty
      return [true,false] if !@user.nil? && @user.is_admin?
      [false]
    end

  end
end
