class AttachmentCacheWorker
  include Sidekiq::Worker

  sidekiq_options queue: :attachment_cache

  def perform(id, directory, force = false)
    @attachment = LearningObject::Attachment.find(id)
    client = DspaceService.create_client
    return false if @attachment.nil? || client.nil?

    @directory = directory
    file_root = AttachmentCacheService.new(@attachment).file_root

    return @attachment.update(cache_link: cache_link) if File.exist?(file_root) && !force

    file = client.bitstreams.retrieve(id: @attachment.id_dspace).open
    begin
      FileUtils.mkdir_p(directory_root)
      FileUtils.mv(file.path, file_root)
      FileUtils.chmod 0644, file_root.to_s, verbose: true
      FileUtils.chown_R 'portalmec', 'www-data', directory_root.to_s, verbose: true
      @attachment.update(cache_link: cache_link)
    ensure
      file.close if !file.nil? && File.exist?(file.path)
    end
  end

  private

  def cache_link
    "/#{file_path}"
  end

  def file_path
    "#{@directory}/#{SanitizationService.filename(@attachment.name)}"
  end

  def directory_root
    Rails.root.join('public', @directory)
  end
end
