require_dependency 'dspace'

class DspaceUploadWorker
  include Sidekiq::Worker

  @@dspace = nil

  def perform(learning_object_id, media_path, attachment_id = nil, description = nil)
    # find learning object
    learning_object = LearningObject.find learning_object_id

    return false if learning_object.blank?

    # Require dspace gem
    Bundler.require(*Rails.groups)

    # create attachment
    file = File.new(media_path, 'r')
    bitstream = dspace.items.add_bitstream(file, id: learning_object.id_dspace, name: File.basename(media_path), description: description)
    attachment = create_attachment(learning_object, bitstream, attachment_id)

    ThumbnailGenerateWorker.perform_async attachment.id, media_path
  end

  private

  def create_attachment(learning_object, bitstream, attachment_id = nil)
    unless attachment_id.nil?
      attachment = learning_object.attachments.find(attachment_id)
      unless attachment.nil?
        attachment.update(map_bitstream2attachment(bitstream))
        return attachment
      end
    end
    learning_object.attachments.create map_bitstream2attachment(bitstream)
  end

  def publisher
    @publisher ||= LearningObjectPublisher.new(dspace)
  end

  def map_bitstream2attachment(bitstream, options = {})
    ::Dspace::AttachmentMapper.call bitstream, options
  end

  def dspace
    @@dspace ||= DspaceService.create_client
  end
end
